# TODO: Fill out this file with information about your package

# HINT: Go back to the object-oriented programming lesson "Putting Code on PyPi" and "Exercise: Upload to PyPi"

# HINT: Here is an example of a setup.py file
# https://packaging.python.org/tutorials/packaging-projects/
from setuptools import setup

setup(
  name = 'TwentyOneCardGame',         # How you named your package folder (MyLib)
  packages = ['TwentyOneCardGame'],   # Chose the same as "name"
  version = '1.23',
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Basic game of Black Jack/21',
  author = 'Patrick Löwe',
  author_email = 'patricklowe33@gmail.com',
  #url = 'https://github.com/user/reponame',
  #download_url = 'https://github.com/user/reponame/archive/v_01.tar.gz',
  keywords = ['GAME', '21', 'BLACK JACK'],
  #install_requires=[],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3.8'],
)


import game_settings
import random

#if __name__ == "__main__":
class Game_Start:
    def __init__(self):
        # Initialize a game
        game = game_settings.Game(game_mode = 'easy', show_card=False)

        # 1) Load Deck
        dealer = game_settings.Person("Dealer")
        print("Player please enter your name:")
        player = game_settings.Person(input())

        # 2) Load Deck
        deck = game_settings.Deck(game)
        deck.Shuffle_deck()

        # 3) Setup game, 2 cards to each person
        game.start(dealer,player,deck)
        # Check for winner/loser
        game.get_Status(dealer,player,deck,False)
        game.print_scores(dealer,player)

        resume = True
        while resume:
            if input("Hit?  [Y/N]:") == 'Y':
                # Player has decided to take another card
                resume = True
                game.do_round(player,deck)
                game.get_Status(dealer,player,deck,False)
                game.print_scores(dealer,player)
                # Dealer decides to do another round
                if random.randint(1,100) % 2 == 0:
                    print("Dealer has decided to hit")
                    game.do_round(dealer,deck)
                    game.get_Status(dealer,player,deck,False)
                    game.print_scores(dealer,player)
                else:
                    game.get_winner(dealer,player)
            else:
                if random.randint(1,100) % 2 == 0:
                    print("Dealer has decided to hit")
                    game.do_round(dealer,deck)
                    game.get_Status(dealer,player,deck,False)
                    game.print_scores(dealer,player)
                else:
                    game.get_winner(dealer,player)